sqltriples.Query.ConjunctionOfTriples

Package sqltriples :: Module Query :: Class ConjunctionOfTriples |
[show private | hide private]
[frames | no frames]

## Class ConjunctionOfTriples

          CombinedResults --+
                            |
                  Conjunction --+
                                |
    AbstractQuery --+           |
                    |           |
                Query --+       |
                        |       |
                  Results --+   |
                            |   |
                      Triples --+
                                |
                               ConjunctionOfTriples

Method Summary
| `__init__(self, store, queries)`
Inherited from CombinedResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`

Class Variable Summary
Inherited from Conjunction
`int` | `in_parentheses` = 1
`str` | `operator` = `'and'`
Inherited from Triples
`list` | `exposed_columns` = `[('subject', 'subject_type'), ('predic...`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net